import React from 'react';
import { useEffect } from 'react';
import { Bot, Target, LineChart, Zap, Mail, Phone, Loader2, CheckCircle2, ArrowRight, MessageSquare, Calendar, BrainCircuit } from 'lucide-react';
import Footer from '../components/Footer';
import { parsePhoneNumber, getCountryCallingCode } from 'libphonenumber-js';

const AILeadDemo = () => {
  useEffect(() => {
    document.title = 'AI Lead Qualification Demo - Smart Lead Nurturing & Conversion | Sales Assist AI';
    // Scroll to top when component mounts
    window.scrollTo({ top: 0, behavior: 'smooth' });
    // Update meta description
    const metaDescription = document.querySelector('meta[name="description"]');
    if (metaDescription) {
      metaDescription.setAttribute('content', 'Try our AI-powered lead qualification system that automatically evaluates, nurtures, and converts leads through personalized engagement journeys. Experience intelligent lead scoring and automated follow-ups in action.');
    }
  }, []);

  const [formState, setFormState] = React.useState({
    name: '',
    email: '',
    phone: ''
  });
  const [phoneError, setPhoneError] = React.useState('');
  const [emailError, setEmailError] = React.useState('');
  const [isSubmitting, setIsSubmitting] = React.useState(false);
  const [success, setSuccess] = React.useState(false);
  const [error, setError] = React.useState('');

  const validateEmail = (email: string) => {
    if (!email) return '';
    
    // Basic email validation regex that ensures:
    // - Has characters before @
    // - Has @ symbol
    // - Has characters between @ and .
    // - Has . followed by at least 2 characters
    const emailRegex = /^[^\s@]+@[^\s@]+\.[^\s@]{2,}$/;
    
    if (!emailRegex.test(email)) {
      return 'Please enter a valid email address (e.g. name@example.com)';
    }
    
    return '';
  };

  const validatePhone = (phone: string) => {
    if (!phone) return 'Phone number is required';
    if (!phone.startsWith('+')) return 'Phone number must start with a country code (e.g. +1)';
    
    try {
      // Try to parse the phone number
      try {
        // First try to parse as is (with potential country code)
        const parsedNumber = parsePhoneNumber(phone);
        if (!parsedNumber.isValid()) {
          return 'Please enter a valid phone number with country code';
        }
        return '';
      } catch {
        return 'Please enter a valid phone number with country code';
      }
    } catch (error) {
      return 'Please enter a valid phone number with country code';
    }
  };

  const handlePhoneChange = (e: React.ChangeEvent<HTMLInputElement>) => {
    let value = e.target.value.replace(/[^\d+]/g, '');
    
    // If the input is empty or doesn't start with +, add it
    if (!value.startsWith('+')) {
      value = '+' + value;
    }
    
    setFormState(prev => ({
      ...prev,
      phone: value
    }));
    
    setPhoneError(validatePhone(value));
  };

  const handleEmailChange = (e: React.ChangeEvent<HTMLInputElement>) => {
    const value = e.target.value;
    
    setFormState(prev => ({
      ...prev,
      email: value
    }));
    
    setEmailError(validateEmail(value));
  };

  const handleSubmit = async (e: React.FormEvent) => {
    e.preventDefault();
    
    // Validate phone before submission
    const phoneValidationError = validatePhone(formState.phone);
    if (phoneValidationError) {
      setPhoneError(phoneValidationError);
      return;
    }
    
    // Validate required fields
    if (!formState.name.trim()) {
      setError('Name is required');
      return;
    }
    if (!formState.email.trim()) {
      setError('Email is required');
      return;
    }
    
    // Validate email before submission
    const emailValidationError = validateEmail(formState.email);
    
    if (emailValidationError) {
      setEmailError(emailValidationError);
      return;
    }
    
    setIsSubmitting(true);
    setError('');

    try {
      const response = await fetch('https://build.salesassistai.com/webhook/salesassist-lead-engagement', {
        method: 'POST',
        headers: {
          'Content-Type': 'application/json',
          'Accept': 'application/json'
        },
        body: JSON.stringify({
          name: formState.name,
          email: formState.email,
          phoneNumber: formState.phone,
          source: 'demo_lead_engagement',
          timestamp: new Date().toISOString()
        })
      });

      if (!response.ok) {
        throw new Error('Failed to submit lead');
      }

      setSuccess(true);
      setFormState({
        name: '',
        email: '',
        phone: ''
      });
    } catch (err) {
      setError('Failed to submit. Please try again.');
    } finally {
      setIsSubmitting(false);
    }
  };

  const handleChange = (e: React.ChangeEvent<HTMLInputElement>) => {
    const { id, value } = e.target;
    setFormState(prev => ({
      ...prev,
      [id]: value
    }));
  };

  return (
    <div>
      <div className="min-h-screen bg-white">
        <div className="container pt-24 pb-12">
          <div className="text-center mb-12">
            <div className="inline-flex items-center gap-2 px-4 py-2 rounded-full bg-primary-50 border border-primary-100 mb-4">
              <div className="p-1 bg-gradient-to-r from-primary-500 to-primary-600 rounded-full">
                <Target className="w-4 h-4 text-white" />
              </div>
              <span className="text-sm font-medium text-primary-700">
                LEAD ENGAGEMENT DEMO
              </span>
            </div>
            
            <h1 className="text-4xl font-bold text-secondary-900 mb-4">
              Smart Lead Engagement &
              <span className="block text-gradient mt-2">Qualification & Nurturing</span>
            </h1>
            <p className="text-xl text-secondary-600 max-w-2xl mx-auto">
              Experience how our AI engages leads through personalized interactions and guides them through intelligent nurturing sequences
            </p>
          </div>

          <div className="max-w-4xl mx-auto">
            <div className="bg-white rounded-3xl border border-primary-100/50 shadow-soft p-8">
              <div className="flex items-center justify-between mb-8">
                <div className="flex items-center space-x-4">
                  <div className="w-12 h-12 rounded-full bg-primary-50 flex items-center justify-center">
                    <Bot className="w-6 h-6 text-primary-600" />
                  </div>
                  <div>
                    <h3 className="text-lg font-semibold text-secondary-900">AI Lead Analysis</h3>
                    <p className="text-sm text-secondary-600">Real-time qualification</p>
                  </div>
                </div>
                <div className="flex items-center gap-2">
                  <div className="w-2 h-2 rounded-full bg-green-500 animate-pulse" />
                  <span className="text-sm font-medium text-green-600">Processing</span>
                </div>
              </div>

              <div className="bg-white rounded-2xl p-6 border border-primary-100/50">
                  <div className="flex items-center gap-3 mb-4">
                    <div className="w-10 h-10 rounded-xl bg-primary-50 flex items-center justify-center">
                      <BrainCircuit className="w-5 h-5 text-primary-600" />
                    </div>
                    <div>
                      <h4 className="font-medium text-secondary-900">Qualification Criteria</h4>
                      <p className="text-sm text-secondary-600">Key indicators analysis</p>
                    </div>
                  </div>
                  <div className="space-y-3">
                    <div className="flex items-center justify-between bg-secondary-50 rounded-xl p-3">
                      <div className="flex items-center gap-2">
                        <div className="w-2 h-2 rounded-full bg-green-500" />
                        <span className="text-sm text-secondary-900">Budget Match</span>
                      </div>
                    </div>
                    <div className="flex items-center justify-between bg-secondary-50 rounded-xl p-3">
                      <div className="flex items-center gap-2">
                        <div className="w-2 h-2 rounded-full bg-green-500" />
                        <span className="text-sm text-secondary-900">Decision Authority</span>
                      </div>
                    </div>
                    <div className="flex items-center justify-between bg-secondary-50 rounded-xl p-3">
                      <div className="flex items-center gap-2">
                        <div className="w-2 h-2 rounded-full bg-green-500" />
                        <span className="text-sm text-secondary-900">Timeline</span>
                      </div>
                      <span className="text-sm font-medium text-green-600">1-3 Months</span>
                    </div>
                  </div>
              </div>

              <div className="mt-6 bg-secondary-50 rounded-2xl p-6 border border-secondary-100">
                <div className="flex items-center gap-3 mb-4">
                  <div className="w-10 h-10 rounded-xl bg-primary-50 flex items-center justify-center">
                    <Zap className="w-5 h-5 text-primary-600" />
                  </div>
                  <div>
                    <h4 className="font-medium text-secondary-900">Engagement Sequence</h4>
                    <p className="text-sm text-secondary-600">Automated nurturing flow</p>
                  </div>
                </div>
                
                <div className="space-y-4">
                  <div className="relative">
                    <div className="absolute left-6 top-0 h-[calc(100%-80px)] w-px bg-primary-200" />
                    <div className="space-y-4">
                      <div className="flex gap-3">
                        <div className="w-12 h-12 rounded-xl bg-green-50 border border-green-100 flex items-center justify-center shrink-0 relative z-10">
                          <Mail className="w-5 h-5 text-green-600" />
                        </div>
                        <div className="bg-white rounded-xl p-4 border border-primary-100/50 flex-1">
                          <div className="flex items-center justify-between mb-1">
                            <h5 className="font-medium text-secondary-900">Welcome Email</h5>
                            <span className="px-2 py-1 rounded-full text-xs bg-green-50 text-green-600 border border-green-100">
                              Completed
                            </span>
                          </div>
                          <p className="text-sm text-secondary-600">Initial contact and information package</p>
                        </div>
                      </div>
                      
                      <div className="flex gap-3">
                        <div className="w-12 h-12 rounded-xl bg-green-50 border border-green-100 flex items-center justify-center shrink-0 relative z-10">
                          <Phone className="w-5 h-5 text-green-600" />
                        </div>
                        <div className="bg-white rounded-xl p-4 border border-primary-100/50 flex-1">
                          <div className="flex items-center justify-between mb-1">
                            <h5 className="font-medium text-secondary-900">Discovery Call</h5>
                            <span className="px-2 py-1 rounded-full text-xs bg-green-50 text-green-600 border border-green-100">
                              Completed
                            </span>
                          </div>
                          <p className="text-sm text-secondary-600">Needs assessment and solution alignment</p>
                        </div>
                      </div>
                      
                      <div className="flex gap-3">
                        <div className="w-12 h-12 rounded-xl bg-blue-50 border border-blue-100 flex items-center justify-center shrink-0 relative z-10">
                          <Calendar className="w-5 h-5 text-blue-600" />
                        </div>
                        <div className="bg-white rounded-xl p-4 border border-primary-100/50 flex-1">
                          <div className="flex items-center justify-between mb-1">
                            <h5 className="font-medium text-secondary-900">Product Demo</h5>
                            <span className="px-2 py-1 rounded-full text-xs bg-blue-50 text-blue-600 border border-blue-100">
                              In Progress
                            </span>
                          </div>
                          <p className="text-sm text-secondary-600">Scheduling personalized platform demonstration</p>
                        </div>
                      </div>
                    </div>
                  </div>
                </div>
              </div>
            </div>

            {/* Mock Website with Lead Form */}
            <div className="relative mt-12">
              <div className="absolute inset-0 bg-gradient-to-br from-primary-500/5 to-primary-600/5 rounded-3xl blur-xl" />
              <div className="relative bg-white rounded-3xl border border-primary-100/50 shadow-soft p-8">
              <div className="text-center mb-8">
                <div className="w-16 h-16 mx-auto rounded-full bg-primary-50 flex items-center justify-center mb-4">
                  <Target className="w-8 h-8 text-primary-600" />
                </div>
                <h3 className="text-xl font-semibold text-secondary-900 mb-2">
                  Try Our AI Lead Qualification
                </h3>
                <p className="text-secondary-600 max-w-xl mx-auto">
                  Submit your information below to experience how our AI agent interacts with new leads. You'll receive personalized follow-ups and see our qualification process in action.
                </p>
                
                <div className="mt-6 grid grid-cols-1 sm:grid-cols-3 gap-4 max-w-2xl mx-auto">
                  <div className="flex items-center gap-3 bg-primary-50 rounded-xl p-3 border border-primary-100">
                    <div className="w-8 h-8 rounded-full bg-white flex items-center justify-center shrink-0">
                      <span className="text-primary-600 font-bold">1</span>
                    </div>
                    <span className="text-sm text-primary-700">Fill the form</span>
                  </div>
                  <div className="flex items-center gap-3 bg-primary-50 rounded-xl p-3 border border-primary-100">
                    <div className="w-8 h-8 rounded-full bg-white flex items-center justify-center shrink-0">
                      <span className="text-primary-600 font-bold">2</span>
                    </div>
                    <span className="text-sm text-primary-700">Submit details</span>
                  </div>
                  <div className="flex items-center gap-3 bg-primary-50 rounded-xl p-3 border border-primary-100">
                    <div className="w-8 h-8 rounded-full bg-white flex items-center justify-center shrink-0">
                      <span className="text-primary-600 font-bold">3</span>
                    </div>
                    <span className="text-sm text-primary-700">Experience AI Response</span>
                  </div>
                </div>
              </div>

              <div className="relative">
                {/* Browser Window Mockup */}
                <div className="bg-gradient-to-r from-secondary-100 to-secondary-50 rounded-t-xl p-4 flex items-center gap-2">
                  <div className="flex gap-2">
                    <div className="w-3 h-3 rounded-full bg-red-400" />
                    <div className="w-3 h-3 rounded-full bg-yellow-400" />
                    <div className="w-3 h-3 rounded-full bg-green-400" />
                  </div>
                  <div className="flex-1 px-4">
                    <div className="bg-white/90 backdrop-blur-sm rounded-full py-1 px-4 text-sm text-secondary-600 text-center">
                      example.com/contact
                    </div>
                  </div>
                </div>

                {/* Website Content */}
                <div className="bg-gradient-to-br from-primary-50/50 to-white p-8 rounded-b-xl">
                  <div className="max-w-xl mx-auto">
                    {success ? (
                      <div className="text-center py-8">
                        <div className="mb-6 transform animate-bounce">
                          <div className="w-16 h-16 mx-auto rounded-full bg-green-100 flex items-center justify-center">
                            <CheckCircle2 className="w-8 h-8 text-green-600" />
                          </div>
                        </div>
                        <h3 className="text-2xl font-semibold text-secondary-900 mb-4">
                          Thanks for Your Interest!
                        </h3>
                        <p className="text-secondary-600 mb-8">
                          Our AI agent will now begin the qualification process. You'll receive follow-up communications to experience our lead nurturing sequence firsthand.
                        </p>
                        <button
                          onClick={() => setSuccess(false)}
                          className="btn-primary"
                        >
                          Submit Another Lead
                        </button>
                      </div>
                    ) : (
                    <form onSubmit={handleSubmit} className="space-y-6">
                      <div>
                        <label htmlFor="name" className="block text-sm font-medium text-secondary-700 mb-1.5">
                          Full Name *
                        </label>
                        <input
                          type="text"
                          id="name"
                          value={formState.name}
                          onChange={handleChange}
                          className="input"
                          required
                        />
                      </div>

                      <div>
                        <label htmlFor="email" className="block text-sm font-medium text-secondary-700 mb-1.5">
                          Email Address *
                        </label>
                        <input
                          type="email"
                          id="email"
                          value={formState.email}
                          onChange={handleEmailChange}
                          className={`input ${emailError ? 'border-red-300 focus:border-red-500' : ''}`}
                          placeholder="john@example.com"
                          required
                        />
                        {emailError && (
                          <p className="mt-1 text-sm text-red-600">{emailError}</p>
                        )}
                      </div>

                      <div>
                        <label htmlFor="phone" className="block text-sm font-medium text-secondary-700 mb-1.5">
                          Phone Number *
                        </label>
                        <input
                          type="tel"
                          id="phone"
                          value={formState.phone}
                          onChange={handlePhoneChange}
                          className={`input ${phoneError ? 'border-red-300 focus:border-red-500' : ''}`}
                          placeholder="1 (555) 123-4567"
                          required
                        />
                        <p className="mt-1 text-sm text-secondary-500">
                          Enter country code followed by number (e.g. 1 for US, 44 for UK)
                        </p>
                        {phoneError && (
                          <p className="mt-1 text-sm text-red-600">{phoneError}</p>
                        )}
                      </div>

                      {error && (
                        <div className="text-red-600 text-sm">
                          {error}
                        </div>
                      )}

                      <button
                        type="submit"
                        disabled={isSubmitting}
                        className="w-full btn-primary relative group"
                      >
                        <span className={isSubmitting ? 'opacity-0' : ''}>
                          Submit & Start AI Interaction
                          <ArrowRight className="ml-2 w-5 h-5 inline-block group-hover:translate-x-0.5 transition-transform" />
                        </span>
                        {isSubmitting && (
                          <div className="absolute inset-0 flex items-center justify-center">
                            <Loader2 className="w-5 h-5 animate-spin" />
                          </div>
                        )}
                      </button>
                      <p className="mt-4 text-sm text-center text-secondary-500">
                        This is a demo - you'll receive demo communications to showcase our AI capabilities
                      </p>
                    </form>
                    )}
                  </div>
                </div>
              </div>
            </div>
            </div>

            <div className="grid grid-cols-1 md:grid-cols-3 gap-6 mt-12">
              <div className="bg-white rounded-2xl p-6 border border-primary-100/50 shadow-soft">
                <div className="text-primary-600 mb-4">
                  <Target className="w-8 h-8" />
                </div>
                <h3 className="text-lg font-semibold text-secondary-900 mb-2">
                  Intelligent Engagement
                </h3>
                <p className="text-secondary-600">
                  AI engages leads with personalized conversations and smart qualification
                </p>
              </div>
              
              <div className="bg-white rounded-2xl p-6 border border-primary-100/50 shadow-soft">
                <div className="text-primary-600 mb-4">
                  <LineChart className="w-8 h-8" />
                </div>
                <h3 className="text-lg font-semibold text-secondary-900 mb-2">
                  Smart Nurturing Paths
                </h3>
                <p className="text-secondary-600">
                  Customized engagement journeys based on lead behavior and interests
                </p>
              </div>
              
              <div className="bg-white rounded-2xl p-6 border border-primary-100/50 shadow-soft">
                <div className="text-primary-600 mb-4">
                  <Zap className="w-8 h-8" />
                </div>
                <h3 className="text-lg font-semibold text-secondary-900 mb-2">
                  Intelligent Follow-ups
                </h3>
                <p className="text-secondary-600">
                  AI adapts timing and channels for maximum engagement effectiveness
                </p>
              </div>
            </div>
          </div>
        </div>
      </div>
      <Footer />
    </div>
  );
}

export default AILeadDemo;